# Generated by Django 4.2 on 2025-01-27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "djinsight",
            "0002_rename_djinsight_p_page_id_a3ba77_idx_djinsight_p_page_id_f86134_idx_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageviewlog",
            name="session_key",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Session key of the visitor",
                max_length=255,
                null=True,
                verbose_name="Session Key",
            ),
        ),
    ]
